aind\_behavior\_curriculum package
==================================

Submodules
----------

aind\_behavior\_curriculum.base module
--------------------------------------

.. automodule:: aind_behavior_curriculum.base
   :members:
   :undoc-members:
   :show-inheritance:

aind\_behavior\_curriculum.curriculum module
--------------------------------------------

.. automodule:: aind_behavior_curriculum.curriculum
   :members:
   :undoc-members:
   :show-inheritance:

aind\_behavior\_curriculum.curriculum\_utils module
---------------------------------------------------

.. automodule:: aind_behavior_curriculum.curriculum_utils
   :members:
   :undoc-members:
   :show-inheritance:

aind\_behavior\_curriculum.task module
--------------------------------------

.. automodule:: aind_behavior_curriculum.task
   :members:
   :undoc-members:
   :show-inheritance:

aind\_behavior\_curriculum.trainer module
-----------------------------------------

.. automodule:: aind_behavior_curriculum.trainer
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_behavior_curriculum
   :members:
   :undoc-members:
   :show-inheritance:
